@@ -3,12 +3,11 @@ import argparse
 import logging
 import pprint
 import time
+from os import environ as env
 from signal import SIGINT, signal
 
 import soco
 
-from os import environ as env
-
 from .action_processor import list_actions, process_action
 from .speakers import Speakers
 from .utils import (
@@ -394,7 +393,9 @@ def main():
                 speaker = get_speaker(speaker_name, use_local_speaker_list)
                 if not speaker:
                     error_and_exit("Speaker '{}' not found".format(speaker_name))
-                if not process_action(speaker, action, args, use_local_speaker_list):
+                if not process_action(
+                    speaker, action, args, use_local_speaker_list=use_local_speaker_list
+                ):
                     error_and_exit("Action '{}' not found".format(action))
 
         except Exception as e:
@@ -434,7 +435,9 @@ def interactive_loop(speaker_name, use_local_speaker_list=False, no_env=False):
                     print("Error: Speaker not found")
                     continue
             action = args.pop(0)
-            response = process_action(speaker, action, args, use_local_speaker_list)
+            response = process_action(
+                speaker, action, args, use_local_speaker_list=use_local_speaker_list
+            )
             if not response:
                 print("Error: Action '{}'".format(action))
         except:
