@@ -27,12 +27,27 @@ def event_unsubscribe(sub):
     logging.info("Unsubscribed")
 
 
+INTERACTIVE = False
+API = False
+
+
+def set_interactive():
+    global INTERACTIVE
+    INTERACTIVE = True
+
+
+def set_api():
+    global API
+    API = True
+
+
 # Error handling
 def error_and_exit(msg):
     # Print to stderr
     print("Error:", msg, file=sys.stderr)
     # Use os._exit() to avoid the catch-all 'except'
-    os._exit(1)
+    if not (INTERACTIVE or API):
+        os._exit(1)
 
 
 def parameter_type_error(action, required_params):
@@ -212,6 +227,17 @@ def docs():
     print("Online documentation for {}: {}".format(version, url))
 
 
+def logo():
+    version = "v{}".format(__version__)
+    if __version__.endswith("+"):
+        url = "https://raw.githubusercontent.com/avantrec/soco-cli/next_version/assets/soco-cli-logo-01-large.png"
+    else:
+        url = "https://raw.githubusercontent.com/avantrec/soco-cli/{}/assets/soco-cli-logo-01-large.png".format(
+            version
+        )
+    print("SoCo-CLI Logo: {}".format(url))
+
+
 # ToDo: Remove with SIGTERM fix
 use_sigterm = False
 
@@ -522,6 +548,12 @@ def configure_common_args(parser):
         default=False,
         help="Print the URL to the online documentation",
     )
+    parser.add_argument(
+        "--logo",
+        action="store_true",
+        default=False,
+        help="Print the URL to the SoCo-CLI logo",
+    )
 
 
 def check_args(args):
